Estimator
=========

.. currentmodule:: pqp.estimation

.. autoclass:: Estimator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Estimator.approx
      ~Estimator.approx_difference
      ~Estimator.approx_expectation
      ~Estimator.approx_marginal
      ~Estimator.approx_p
      ~Estimator.approx_product
      ~Estimator.approx_quotient
      ~Estimator.estimate
      ~Estimator.get_observed

   .. rubric:: Methods Documentation

   .. automethod:: approx
   .. automethod:: approx_difference
   .. automethod:: approx_expectation
   .. automethod:: approx_marginal
   .. automethod:: approx_p
   .. automethod:: approx_product
   .. automethod:: approx_quotient
   .. automethod:: estimate
   .. automethod:: get_observed
